package spacedata_test

import (
	"fmt"

	"mfs.de/spacedata"
)

func ExampleLocationProvider_EndpointString() {
	providerInTesting := spacedata.LocationProvider{}
	fmt.Println(providerInTesting.EndpointString())
	// Output:
	// http://api.open-notify.org/iss-now.json
}

func ExampleLocationProvider_ParseResponse() {
	providerInTesting := spacedata.LocationProvider{}

	sampleJson := "{\"iss_position\":{\"longitude\":\"72.7034\",\"latitude\":\"-27.4969\"},\"message\":\"success\"}"
	jsonData, err := providerInTesting.ParseResponse([]byte(sampleJson))
	fmt.Println(err)
	fmt.Println(string(jsonData))
	// Output:
	// <nil>
	// {"latitude":"-27.4969","longitude":"72.7034"}
}

func ExamplePassTimeProvider_EndpointString() {
	providerInTesting := spacedata.PassTimeProvider{}
	fmt.Println(providerInTesting.EndpointString())
	// Output:
	// http://api.open-notify.org/iss-pass.json
}

func ExamplePassTimeProvider_ParseResponse() {
	providerInTesting := spacedata.PassTimeProvider{}
	// Endpoint requires params `lat` and `lon`, like:
	// "http://api.open-notify.org/iss-pass.json?lat=39.4384&lon=36.3098"

	sampleJson := "{\"message\":\"success\",\"response\":[{\"duration\": 526,\"risetime\":1568584396},{\"duration\":585,\"risetime\":1568590236}]}"
	jsonData, err := providerInTesting.ParseResponse([]byte(sampleJson))
	fmt.Println(err)
	fmt.Println(string(jsonData))
	// Output:
	// <nil>
	// [{"risetime":1568584396,"duration":526},{"risetime":1568590236,"duration":585}]
}

func ExamplePeopleProvider_EndpointString() {
	providerInTesting := spacedata.PeopleProvider{}
	fmt.Println(providerInTesting.EndpointString())
	// Output:
	// http://api.open-notify.org/astros.json
}

func ExamplePeopleProvider_ParseResponse() {
	providerInTesting := spacedata.PeopleProvider{}
	sampleJson := "{\"message\":\"success\",\"people\":[{\"name\":\"Alexey Ovchinin\",\"craft\":\"ISS\"},{\"name\":\"Christina Koch\",\"craft\":\"ISS\"}],\"number\": 2}"
	jsonData, err := providerInTesting.ParseResponse([]byte(sampleJson))
	fmt.Println(err)
	fmt.Println(string(jsonData))
	// Output:
	// <nil>
	// {"ISS":["Alexey Ovchinin","Christina Koch"]}
}
