package spacedata

import (
	"bytes"
	"encoding/json"
	"errors"
	"fmt"
	"mfs.de/gps"
	"strconv"
	"time"
)

type LocationProvider struct {
	lastRequestTimestamp int64
}

type Coordinate struct {
	Latitude  string `json:"latitude"`
	Longitude string `json:"longitude"`
}

func (c Coordinate) GpsCoordinate() gps.Coordinates {
	lat, err := strconv.ParseFloat(c.Latitude, 64)
	if err != nil {
		fmt.Printf("Parsing latitude from spacedata.Coordinate %#v failed: error: %v", c, err)
		lat = 0
	}
	lon, err := strconv.ParseFloat(c.Longitude, 64)
	if err != nil {
		fmt.Printf("Parsing longitude from spacedata.Coordinate %#v failed: error: %v", c, err)
		lon = 0
	}
	return gps.CoordinatesWithLatLong(lat, lon)
}

type issNowJson struct {
	Timestamp  int64  `json:"timestamp"`
	Message    string `json:"message"`
	Coordinate `json:"iss_position"`
}

func (l LocationProvider) EndpointString() string {
	return "http://api.open-notify.org/iss-now.json"
}

func (l LocationProvider) ParseResponse(jsonData []byte) ([]byte, error) {
	if jsonData == nil || len(jsonData) == 0 {
		return nil, errors.New("empty or unset jsonData parameter")
	}
	currentTimestamp := time.Now().Unix()
	l.lastRequestTimestamp = currentTimestamp

	temporaryResultValue := issNowJson{}

	decoder := json.NewDecoder(bytes.NewReader(jsonData))
	err := decoder.Decode(&temporaryResultValue)

	if err != nil {
		return nil, err
	}
	if temporaryResultValue.Message != "success" {
		return nil, errors.New("result json contains error message: " + temporaryResultValue.Message)
	}

	return temporaryResultValue.jsonData()
}

func (c *issNowJson) jsonData() ([]byte, error) {
	issCoordinates := c.Coordinate
	return encodeJson(issCoordinates)
}
