package spacedata

import (
	"bytes"
	"encoding/json"
	"errors"
	"time"
)

type PeopleProvider struct {
	lastRequestTimestamp int64
	cachedResult         []byte
	DatabaseDirectory    string
}

type peopleInSpace struct {
	Message string       `json:"message"`
	Amount  int64        `json:"number"`
	Payload []Astronauts `json:"people"`
}

type Astronauts struct {
	Name string `json:"name"`
	Ship string `json:"craft"`
}

func (p PeopleProvider) EndpointString() string {
	return "http://api.open-notify.org/astros.json"
}

func (p PeopleProvider) ParseResponse(jsonData []byte) ([]byte, error) {
	if jsonData == nil || len(jsonData) == 0 {
		return nil, errors.New("empty or unset jsonData parameter")
	}
	currentTimestamp := time.Now().Unix()
	p.lastRequestTimestamp = currentTimestamp

	temporaryResultValue := peopleInSpace{}

	decoder := json.NewDecoder(bytes.NewReader(jsonData))
	err := decoder.Decode(&temporaryResultValue)

	if err != nil {
		return nil, err
	}
	if temporaryResultValue.Message != "success" {
		return nil, errors.New("result json contains error message: " + temporaryResultValue.Message)
	}

	storage := PeopleStorage{DatabaseName: "peopleInSpace.db", DatabasePath: p.DatabaseDirectory}
	for _, whatever := range temporaryResultValue.Payload {
		toStore := PeopleDataSet{Name: whatever.Name, Craft: whatever.Ship}
		_, _ = storage.Post(&toStore)
	}

	return temporaryResultValue.jsonData()
}

func (p peopleInSpace) jsonData() ([]byte, error) {
	result := make(map[string][]string, len(p.Payload))
	for _, guy := range p.Payload {
		if result[guy.Ship] == nil {
			list := make([]string, 1)
			list[0] = guy.Name
			result[guy.Ship] = list
		} else {
			result[guy.Ship] = append(result[guy.Ship], guy.Name)
		}
	}
	return encodeJson(result)
}
